==> haskell-uuid-types-1.0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
key: uuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
abi: 93dfce6fff71cb16a79ac7785c85837f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-types-1.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-9AR9NqIFJzo61iW1wAnWIZ
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-Ehz3Hb8wPTNLGYb3sWO6HS
key: uuid-types-1.0.3-Ehz3Hb8wPTNLGYb3sWO6HS
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
abi: 0b1c0f5a780792af382a976cabb59619
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/uuid-types-1.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-Ehz3Hb8wPTNLGYb3sWO6HS
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
